@@ -14,7 +14,7 @@ from .gui import Ui_MainWindow as UiMainWindow
 from ._threading import map_processes
 from .optimize import open_image, save_image
 
-BASE_PATH = os.path.dirname(os.path.abspath(__file__))
+BASE_PATH = os.path.abspath(os.getcwd())
 
 
 class MainPage(QMainWindow, UiMainWindow):
